--- a/controlpanelplugins/langandregplugin/src/cplanguageview.cpp Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelplugins/langandregplugin/src/cplanguageview.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -137,7 +137,7 @@
* Create region item.
*/
HbDataFormModelItem *regionItem = new HbDataFormModelItem(HbDataFormModelItem::ComboBoxItem,
- hbTrId("Region"));
+ hbTrId("txt_cp_setlabel_region"));
int regionIndex = mSupportedRegions.indexOf(setting.regionId);
@@ -480,8 +480,22 @@
HbLocaleUtil::changeRegion(mCurrentSetting.regionId);
HbInputSettingProxy::instance()->setGlobalInputLanguage(mCurrentSetting.primaryWritingLan);
- //update combobox
- mCurrentPrimaryInputLanguageItem->setContentWidgetData("currentIndex",mPrimaryInputLanguages.indexOf(mCurrentSetting.primaryWritingLan));
+ //update index of primary writing language combobox
+ int primaryInputIndex = mPrimaryInputLanguages.indexOf(mCurrentSetting.primaryWritingLan); //exact match
+ if (primaryInputIndex < 0) { //exach match failed. partially match the language part.
+ for (int i = 0; i < mPrimaryInputLanguages.count();i++) {
+ if (mPrimaryInputLanguages.at(i).language() == mCurrentSetting.primaryWritingLan.language()) {
+ primaryInputIndex = i;
+ mCurrentSetting.primaryWritingLan = mPrimaryInputLanguages.at(i);
+ setting->primaryWritingLan = mPrimaryInputLanguages.at(i);
+ break;
+ }
+ }
+ }
+
+ mCurrentPrimaryInputLanguageItem->setContentWidgetData("currentIndex",primaryInputIndex);
+
+ //update index of region combobox
mCurrentRegionItem->setContentWidgetData("currentIndex",mSupportedRegions.indexOf(mCurrentSetting.regionId));
CPLANG_LOG(QString("Primary writing:") + HbInputSettingProxy::instance()->globalInputLanguage().asString());
--- a/controlpanelplugins/langandregplugin/src/extendedlocaleutil.cpp Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelplugins/langandregplugin/src/extendedlocaleutil.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -1,27 +1,20 @@
-/****************************************************************************
-**
-** Copyright (C) 2008-2010 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Contact: Nokia Corporation (developer.feedback@nokia.com)
-**
-** This file is part of the HbCore module of the UI Extensions for Mobile.
-**
-** GNU Lesser General Public License Usage
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at developer.feedback@nokia.com.
-**
-****************************************************************************/
+/*
+ * Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies).
+ * All rights reserved.
+ * This component and the accompanying materials are made available
+ * under the terms of "Eclipse Public License v1.0""
+ * which accompanies this distribution, and is available
+ * at the URL "http://www.eclipse.org/legal/epl-v10.html".
+ *
+ * Initial Contributors:
+ * Nokia Corporation - initial contribution.
+ *
+ * Contributors:
+ *
+ * Description:
+ *
+ */
+
#include "extendedlocaleutil.h"
#if defined(Q_OS_SYMBIAN)
--- a/controlpanelui/src/cpapplication/cpapplication.pri Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpapplication/cpapplication.pri Mon Oct 18 09:56:50 2010 +0800
@@ -15,10 +15,12 @@
#
HEADERS += src/cpmainview.h \
- src/cpmainwindow.h \
- src/cpmainmodel.h
+ src/cpmainwindow.h \
+ src/cpmainmodel.h \
+ src/cpapplication.h
SOURCES += src/main.cpp \
src/cpmainview.cpp \
src/cpmainwindow.cpp \
- src/cpmainmodel.cpp
\ No newline at end of file
+ src/cpmainmodel.cpp \
+ src/cpapplication.cpp
\ No newline at end of file
--- /dev/null Thu Jan 01 00:00:00 1970 +0000
+++ b/controlpanelui/src/cpapplication/src/cpapplication.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -0,0 +1,52 @@
+/*
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0""
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+*
+*/
+
+#include "cpapplication.h"
+
+/*!
+ CpApplication
+ Inherit HbApplication, mainly used for emit applicationReady Signal.
+ */
+
+/*!
+ \fn void CpApplication::applicationReady()
+
+ This signal is emitted when mainwindow has constructed, used for Matti test.
+*/
+
+/*!
+ constructor.
+ */
+CpApplication::CpApplication(int &argc, char *argv[]):
+ HbApplication(argc, argv)
+{
+}
+
+/*!
+ Destructor.
+ */
+CpApplication::~CpApplication()
+{
+}
+
+/*!
+ Emit applicationReady
+*/
+void CpApplication::handleAppReady()
+{
+ emit applicationReady();
+}
--- /dev/null Thu Jan 01 00:00:00 1970 +0000
+++ b/controlpanelui/src/cpapplication/src/cpapplication.h Mon Oct 18 09:56:50 2010 +0800
@@ -0,0 +1,35 @@
+/*
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0""
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+*
+*/
+
+#ifndef CPAPPLICATION_H
+#define CPAPPLICATION_H
+
+#include <hbapplication.h>
+
+class CpApplication : public HbApplication
+{
+ Q_OBJECT
+public:
+ CpApplication(int &argc, char *argv[]);
+ virtual ~CpApplication();
+ void handleAppReady();
+
+signals:
+ void applicationReady();
+};
+
+#endif /* CPAPPLICATION_H */
--- a/controlpanelui/src/cpapplication/src/cpmainwindow.h Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpapplication/src/cpmainwindow.h Mon Oct 18 09:56:50 2010 +0800
@@ -28,11 +28,6 @@
~CpMainWindow();
public:
virtual bool event(QEvent *e);
-signals:
- /**
- * Emit when control panel's startup is finished
- */
- void applicationReady();
private slots:
void onStartupFininshed();
--- a/controlpanelui/src/cpapplication/src/main.cpp Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpapplication/src/main.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -15,7 +15,7 @@
*
*/
-#include <hbapplication.h>
+#include "cpapplication.h"
#include <cpmainwindow.h>
#include <cpmainview.h>
#include <hbstyleloader.h>
@@ -27,7 +27,7 @@
int main(int argc, char **argv)
{
- HbApplication app(argc, argv);
+ CpApplication app(argc, argv);
//used by QSettings
QCoreApplication::setOrganizationName("nokia");
--- a/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/firstpluginforcpcategorymodel/src/firstpluginforcpcategorymodel.cpp Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/firstpluginforcpcategorymodel/src/firstpluginforcpcategorymodel.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -1,3 +1,20 @@
+/*
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0""
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+*
+*/
+
#include "firstpluginforcpcategorymodel.h"
#include "firstpluginviewforcpcategorymodel.h"
#include <cpsettingformentryitemdataimpl.h>
--- a/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/firstpluginforcpcategorymodel/src/firstpluginforcpcategorymodel.h Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/firstpluginforcpcategorymodel/src/firstpluginforcpcategorymodel.h Mon Oct 18 09:56:50 2010 +0800
@@ -1,3 +1,20 @@
+/*
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0""
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+*
+*/
+
#ifndef FIRSTPLUGINFORCPCATEGORYMODEL_H
#define FIRSTPLUGINFORCPCATEGORYMODEL_H
--- a/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/firstpluginforcpcategorymodel/src/firstpluginviewforcpcategorymodel.cpp Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/firstpluginforcpcategorymodel/src/firstpluginviewforcpcategorymodel.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -1,3 +1,20 @@
+/*
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0""
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+*
+*/
+
#include "firstpluginviewforcpcategorymodel.h"
#include <hbdataform.h>
--- a/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/firstpluginforcpcategorymodel/src/firstpluginviewforcpcategorymodel.h Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/firstpluginforcpcategorymodel/src/firstpluginviewforcpcategorymodel.h Mon Oct 18 09:56:50 2010 +0800
@@ -1,3 +1,20 @@
+/*
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0""
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+*
+*/
+
#ifndef FIRSTPLUGINVIEWFORCPCATEGORYMODEL_H
#define FIRSTPLUGINVIEWFORCPCATEGORYMODEL_H
--- a/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/secondpluginforcpcategorymodel/src/secondpluginforcpcategorymodel.cpp Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/secondpluginforcpcategorymodel/src/secondpluginforcpcategorymodel.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -1,3 +1,20 @@
+/*
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0""
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+*
+*/
+
#include "secondpluginforcpcategorymodel.h"
#include "secondpluginviewforcpcategorymodel.h"
#include <cpsettingformentryitemdataimpl.h>
--- a/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/secondpluginforcpcategorymodel/src/secondpluginforcpcategorymodel.h Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/secondpluginforcpcategorymodel/src/secondpluginforcpcategorymodel.h Mon Oct 18 09:56:50 2010 +0800
@@ -1,3 +1,20 @@
+/*
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0""
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+*
+*/
+
#ifndef SECONDPLUGINFORCPCATEGORYMODEL_H
#define SECONDPLUGINFORCPCATEGORYMODEL_H
--- a/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/secondpluginforcpcategorymodel/src/secondpluginviewforcpcategorymodel.cpp Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/secondpluginforcpcategorymodel/src/secondpluginviewforcpcategorymodel.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -1,3 +1,20 @@
+/*
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0""
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+*
+*/
+
#include "secondpluginviewforcpcategorymodel.h"
#include <hbdataform.h>
--- a/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/secondpluginforcpcategorymodel/src/secondpluginviewforcpcategorymodel.h Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpcategorymodel/tsrc/testpluginsforcpcategorymodel/secondpluginforcpcategorymodel/src/secondpluginviewforcpcategorymodel.h Mon Oct 18 09:56:50 2010 +0800
@@ -1,3 +1,20 @@
+/*
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0""
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+*
+*/
+
#ifndef SECONDPLUGINVIEWFORCPCATEGORYMODEL_H
#define SECONDPLUGINVIEWFORCPCATEGORYMODEL_H
--- a/controlpanelui/src/cpcategorymodel/tsrc/ut_categorymodelutility/src/cptestpluginentryitem.cpp Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpcategorymodel/tsrc/ut_categorymodelutility/src/cptestpluginentryitem.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -1,3 +1,20 @@
+/*
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0""
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+*
+*/
+
#include "CpTestPluginEntryItem.h"
#include <cpitemdatahelper.h>
--- a/controlpanelui/src/cpcategorymodel/tsrc/ut_categorymodelutility/src/cptestpluginentryitem.h Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpcategorymodel/tsrc/ut_categorymodelutility/src/cptestpluginentryitem.h Mon Oct 18 09:56:50 2010 +0800
@@ -1,3 +1,20 @@
+/*
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+* All rights reserved.
+* This component and the accompanying materials are made available
+* under the terms of "Eclipse Public License v1.0""
+* which accompanies this distribution, and is available
+* at the URL "http://www.eclipse.org/legal/epl-v10.html".
+*
+* Initial Contributors:
+* Nokia Corporation - initial contribution.
+*
+* Contributors:
+*
+* Description:
+*
+*/
+
#ifndef CPTESTPLUGINENTRYITEM_H
#define CPTESTPLUGINENTRYITEM_H
#include <cpsettingformentryitemdata.h>
--- a/controlpanelui/src/cpplugins/personalizationplugin/src/cpprofilesettingform.cpp Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpplugins/personalizationplugin/src/cpprofilesettingform.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -26,6 +26,7 @@
#include <cpprofilemonitor.h>
#include <hbslider.h>
#include <hbaction.h>
+#include <hbmessagebox.h>
#include <QFileInfo>
#include <QFileIconProvider>
@@ -401,11 +402,21 @@
void CpProfileSettingForm::onEditNameDialogClosed(HbAction *action)
{
+ QStringList profileNameList(mProfileModel->profileNames());
QString editText(mEditProfileNameDialog->lineEditText());
if (action == mOkButton && mProfileName != editText) {
-
- mProfileModel->setProfileName(mCurrentProfileId, editText);
+ //two profiles can not have the same names.
+ if (profileNameList.contains(editText, Qt::CaseSensitive)) {
+ HbMessageBox::warning(hbTrId("txt_cp_info_cannot_rename_profile_name_already_ex"),\
+ this , SLOT(onWarningNoteClosed()));
+ } else {
+ mProfileModel->setProfileName(mCurrentProfileId, editText);
+ }
}
}
+void CpProfileSettingForm::onWarningNoteClosed()
+{
+ on_editNameAction_triggered();
+}
//End of File
--- a/controlpanelui/src/cpplugins/personalizationplugin/src/cpprofilesettingform.h Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpplugins/personalizationplugin/src/cpprofilesettingform.h Mon Oct 18 09:56:50 2010 +0800
@@ -75,7 +75,7 @@
void onProfileNameChanged();
void on_editNameAction_triggered();
void onEditNameDialogClosed(HbAction *action);
-
+ void onWarningNoteClosed();
private:
void initModel();
void initGeneralTonesGroup();
--- a/controlpanelui/src/cpringtoneview/src/cpringtoneview.cpp Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpringtoneview/src/cpringtoneview.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -71,12 +71,7 @@
}
void CpRingToneView::itemActivated( const QModelIndex &index )
-{
- //avoid responding to the second or later consecutive click
- if (mProcessing) {
- return;
- }
- mProcessing = true;
+{
int nRow = index.row();
switch(nRow) {
case 0: //no tone, set default no sound
@@ -84,10 +79,20 @@
emit aboutToClose();
break;
case 1: { //tone
+ //avoid responding to the second or later consecutive click
+ if (mProcessing) {
+ return;
+ }
+ mProcessing = true;
launchMediaFetcher( "com.nokia.symbian.IToneFetch", "fetch()" );
break;
}
- case 2: { //music
+ case 2: { //music
+ //avoid responding to the second or later consecutive click
+ if (mProcessing) {
+ return;
+ }
+ mProcessing = true;
XQRequestInfo requestInfo;
requestInfo.setInfo("WindowTitle", QVariant(hbTrId("txt_cp_title_control_panel")));
launchMediaFetcher("com.nokia.symbian.IMusicFetch", "fetch()", QList<QVariant>(), requestInfo );
--- a/controlpanelui/src/cpserviceprovider/src/main.cpp Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpserviceprovider/src/main.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -23,7 +23,7 @@
int main(int argc, char **argv)
{
- HbApplication app(argc,argv );
+ HbApplication app(argc,argv, Hb::NoSplash);
#ifdef ENABLE_CPSP_LOG
INIT_LOGGER(CPSP_LOGGER_NAME,CPSP_LOGGER_CONFIG_PATH)
--- a/controlpanelui/src/tonefetcher/src/main.cpp Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/tonefetcher/src/main.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -23,7 +23,7 @@
int main(int argc, char *argv[])
{
- HbApplication a(argc, argv);
+ HbApplication a(argc, argv, Hb::NoSplash);
#ifdef ENABLE_TONEFETCHER_LOG
Logger::instance(TONEFETCHER_LOGGER_NAME)->configure(
--- a/controlpanelui/src/tonefetcher/tonefetcher.pro Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/tonefetcher/tonefetcher.pro Mon Oct 18 09:56:50 2010 +0800
@@ -56,10 +56,7 @@
SERVICE.FILE = service_conf.xml
SERVICE.OPTIONS = embeddable
-SERVICE.OPTIONS += hidden
-libFiles.sources = xqservice.dll
-libFiles.path = "!:\sys\bin"
-DEPLOYMENT += libFiles
+SERVICE.OPTIONS += hidden
symbian:MMP_RULES += SMPSAFE
--- a/controlpanelui/src/cpapplication/src/cpmainwindow.cpp Thu Sep 30 16:15:53 2010 +0800
+++ b/controlpanelui/src/cpapplication/src/cpmainwindow.cpp Mon Oct 18 09:56:50 2010 +0800
@@ -15,6 +15,7 @@
*
*/
+#include "cpapplication.h"
#include "cpmainwindow.h"
#include "cpmainview.h"
#include <cpplugininterface.h>
@@ -58,9 +59,12 @@
*/
void CpMainWindow::onStartupFininshed()
{
// emit applicationReady signal when the all initilizing event has been deal with.
// only emit it once
- emit applicationReady();
+ if( CpApplication *app = qobject_cast<CpApplication *>(qApp)) {
+ app->handleAppReady();
+ }
if (mStartupTimer != 0) {
mStartupTimer->stop();
delete mStartupTimer;
@@ -58,9 +59,12 @@
void CpMainWindow::onStartupFininshed()
{
- // emit applicationReady signal when the all initilizing event has been deal with.
+ // call CpApplication's handleAppReady()
+ // to emit applicationReady signal when the all initilizing events have been dealt with.
// only emit it once